@@ -79,6 +79,14 @@ typedef enum {
 	_BLUETOOTH_NUM_COLUMNS /*< skip >*/
 } BluetoothColumn;
 
+typedef enum {
+	BLUETOOTH_STATUS_INVALID = 0,
+	BLUETOOTH_STATUS_DISCONNECTED,
+	BLUETOOTH_STATUS_CONNECTED,
+	BLUETOOTH_STATUS_CONNECTING,
+	BLUETOOTH_STATUS_PLAYING
+} BluetoothStatus;
+
 G_END_DECLS
 
 #endif /* __BLUETOOTH_ENUMS_H */
